*--------------------------------------------------*
*	simulating the data for a power analysis
*--------------------------------------------------*

clear

set obs 8
gen sets = ""
local set1 "HF exc1,HM exc2,LF l1,HF exc3,LM l2,LM l3"  
local set2 "HM exc1,HF exc2,LF l1,HF exc3,LM l2,LF l3"  
local set3 "HF exc1,HM exc2,LM l1,HF exc3,LF l2,LM l3"   
local set4 "HM exc1,HF exc2,LM l1,HF exc3,LM l2,LM l3"  
local set5 "HF exc1,HM exc2,LF l1,LF l2,LF l3,LM l4"    
local set6 "HM exc1,HF exc2,LF l1,LF l2,LM l3,LM l4"
local set7 "HF exc1,HM exc2,LM l1,LM l2,LF l3,LF l4"
local set8 "HM exc1,HF exc2,LM l1,LM l2,LM l3,LF l4"			

forvalues i = 1 /8{
replace sets = "`set`i''" if _n==`i'
}			

forvalues i = 1/5{
gen cv`i'    = substr(sets, 1, strpos(sets, ",")-1)
replace sets = substr(sets, strpos(sets, ",")+1,. )		
}
gen cv6 = sets
drop sets

gen sets=_n
		
forvalues i = 1/6{

** Independent CV characteristics	
	gen type_cv`i'  = substr(cv`i' , 1,1) =="H"    // High type    
	gen sex_cv`i'   = substr(cv`i' , 2,1) =="F"    // Female CV
	gen fe_cv`i'    = word(cv`i',2)
	
	if `i' <4  gen minority_cv`i'   = inlist(_n,3,4,7,8) & sex_cv`i'==1
	if `i' >3  gen minority_cv`i'   = inlist(_n,1,4,6,8) & sex_cv`i'==1

	order cv`i' , before(type_cv`i')
	}
	
 

expand 2, gen(binding)

save ../data/simulations/exp_collection.dta, replace





** Data generating process
*------------------------------------------

capture program drop hyp1
program define hyp1 , rclass

syntax , nobs(numlist) means(numlist) sd(numlist) t_binding(numlist) [t_minority(numlist)]

tokenize `means'
local mean_hm `1'
local mean_hf `2'
local mean_lm `3'
local mean_lf `4'

tokenize `sd'
local sd_hm `1'
local sd_hf `2'
local sd_lm `3'
local sd_lf `4'

tokenize `t_binding'
local t_h `1'
local t_l `2'

tokenize `t_minority'
local t_m `1'

quiet{ 
preserve
gen numb_obs = rbinomial(`nobs' , 1/16 )

expand numb_obs
gen pid = _n

reshape long cv type_cv sex_cv fe_cv minority_cv, j(pos_set) i(pid)

encode fe_cv, gen(cv_n)

** How do people evaluate CV's
gen cv_score = rnormal(`mean_hm', `sd_hm') * (type_cv==1 & sex_cv==0) + ///
               rnormal(`mean_hf', `sd_hf') * (type_cv==1 & sex_cv==1) + ///
               rnormal(`mean_lm', `sd_lm') * (type_cv==0 & sex_cv==0) + ///
			   rnormal(`mean_lf', `sd_lf') * (type_cv==0 & sex_cv==1)
	      
replace cv_score = cv_score - `t_h' if type_cv==1 & sex_cv==1 & binding ==1
replace cv_score = cv_score - `t_l' if type_cv==0 & sex_cv==1 & binding ==1
capture  replace cv_score = cv_score - `t_m' if minority_cv==1

replace cv_score = max(min(cv_score, 100), 0)	

}

reg cv_score sex_cv##binding   if inlist(fe_cv, "exc1" , "exc2" , "l2" , "l3" , "l4") , a(cv_n)
testparm sex_cv#binding
 
return scalar tau_bind  = _b[1.sex_cv#1.binding] 
return scalar pvalue = `r(p)'

reg cv_score sex_cv minority  if inlist(fe_cv, "exc1" , "exc2" , "l2" , "l3" , "l4") , a(cv_n)
testparm minority

return scalar tau_min  = _b[minority] 
return scalar pvalue_min = `r(p)'

end




** ACTUAL SIMULATIONS
*-------------------------------------------



* Parameters for the simulation
*-------------------------------------

global p = 1/2 * 1/8    // Number of combinations EO x CV
global n = 600         // target sample size

* Parameters of perceived competence taken from Gerxhani et al (2023)
* In our case, the question is 1-100, in their case is discrete in 1-7
* The proposed parameters are an average of DEU and ITA

global tau_H     = 0.173/7 * 100
global mean_HM   = (5.18 + 5.34)* 1/2 * 1/7 * 100
global sd_HM     = (1.42 + 1.34)* 1/2 * 1/7 * 100

global mean_HF   = (5.33 + 5.24)* 1/2 * 1/7 * 100
global sd_HF     = (1.41 + 1.38)* 1/2 * 1/7 * 100

global tau_L     = 0.173/7 * 100    
global mean_LM   = $mean_HM - $sd_HM
global sd_LM     = $sd_HM

global mean_LF   = $mean_HF - $sd_HF
global sd_LF     = $sd_HF

 
file open lucas using ../data/simulations/sample_size_klarita.csv , write replace
file write lucas "sample_size , power" _n

forvalues ss = 2.30103(0.1)4.60103 {

local sample_size = round(10^`ss' , 1) 

use ../data/simulations/exp_collection , clear
simulate pval = r(pvalue) tau_bind= r(tau_bind) , reps(500) seed(3456) saving(../data/n_`sample_size', replace)  :  ///
         hyp1 , nobs(`sample_size') means($mean_HM $mean_HF $mean_LM $mean_LM) ///
		 sd($sd_HM $sd_HF $sd_LM $sd_LM) t_binding($tau_H $tau_L) t_minority(0.01)

count if pval<0.1		 
local pct_reject = `r(N)'/500



	file write lucas  "`sample_size' , `pct_reject'" _n
		 
		 }
		 
		file close lucas 
		 

		 
		 

* Parameters of perceived competence as in Henningsen et al (2022 -- Sex Roles)
global mean_HM   = (87.18 + 86.10 + 85.59 + 88.57)* 1/4
global sd_HM     = (9.82 + 10.47 + 10.99 + 9.95)  * 1/4

global mean_HF   = (87.86 + 88.84 + 86.65 + 88.99)* 1/4
global sd_HF     = (11.09 + 11.19 + 1053 + 10.35) * 1/4

global mean_LM   = $mean_HM - $sd_HM
global sd_LM     = $sd_HM

global mean_LF   = $mean_HF - $sd_HF
global sd_LF     = $sd_HF

global tau_H     = 2.83        // Effect for the H
global tau_L     = 2.83        // Effect for the L

global tau_M     = 2.83

		 
		 
capture file close lucas
file open lucas using ../data/simulations/sample_size_Henningsen.csv , write replace
file write lucas "sample_size , power" _n

forvalues ss = 2.30103(0.1)4.60103 {

local sample_size = round(10^`ss' , 1) 

use ../data/simulations/exp_collection , clear
simulate pval = r(pvalue) tau_bind= r(tau_bind) , reps(500) seed(3456) saving(../data/n2_`sample_size', replace)  :  ///
         hyp1 , nobs(`sample_size') means($mean_HM $mean_HF $mean_LM $mean_LM) ///
		 sd($sd_HM $sd_HF $sd_LM $sd_LM) t_binding($tau_H $tau_L ) t_minority(0.01)

count if pval<0.1		 
local pct_reject = `r(N)'/500

	file write lucas "`sample_size' , `pct_reject'" _n
		 
		 }
		 
		file close lucas 
	
	
import delimited "../data/simulations/sample_size_Henningsen.csv", clear 
ren power power_H
label var power_H "Parameters from Henningsen et al"
save 	"..\data\sample_size_Henningsen", replace
	

import delimited "../data/simulations/sample_size_Klarita.csv", clear 
ren power power_K
label var power_K "Parameters from Gerxhani et al"


merge 1:1 sample_size using ../data/simulations/sample_size_Henningsen 		 		 


gen size2= log10(sample_size)


twoway line power_H power_K size2 , ytitle("Power") xtitle("Sample size" "(log scale)") ///
		  xlabel(2.3 "200" 2.7 "500" 3 "1 k" 3.7 "5 k" 4 "10 k" 4.3 "20 k" 4.6 "40 k")  ///
		  ylab(0(0.25)1) ///
		  legend( order( - "Parameters from:" 1 "Henningsen et al" 2 "Gerxhani et al") ///
		  c(1) pos(3) ring(0))

graph export ../results/power_by_sample_logscale.pdf , as(pdf) replace


twoway line power_H power_K sample_size , ytitle("Power") xtitle("Sample size") ///
		  ylab(0(0.25)1) ///
		  legend( order( - "Parameters from:" 1 "Henningsen et al" 2 "Gerxhani et al") ///
		  c(1) pos(3) ring(0))


graph export ../results/power_by_sample_size.pdf , as(pdf) replace

		 
		 
* FIgure 2
*----------------------------------------



* Parameters of perceived competence taken from Gerxhani et al (2023)
* In our case, the question is 1-100, in their case is discrete in 1-7
* The proposed parameters are an average of DEU and ITA

global tau_H     = 0.173/7 * 100
global mean_HM   = (5.18 + 5.34)* 1/2 * 1/7 * 100
global sd_HM     = (1.42 + 1.34)* 1/2 * 1/7 * 100

global mean_HF   = (5.33 + 5.24)* 1/2 * 1/7 * 100
global sd_HF     = (1.41 + 1.38)* 1/2 * 1/7 * 100

global tau_L     = 0.173/7 * 100    
global mean_LM   = $mean_HM - $sd_HM
global sd_LM     = $sd_HM

global mean_LF   = $mean_HF - $sd_HF
global sd_LF     = $sd_HF

 
 capture file close lucas
file open lucas using ../data/simulations/sample_size_point_estimates.csv , write replace
file write lucas "sample_size , power , tau" _n

forvalues ss = 2.30103(0.1)3.60103 {

local sample_size = round(10^`ss' , 1) 

local power = 0 
local tau = 0
while `power' <0.8 & `tau' < 75 {

local ++tau
local tt  = `tau'/10

use ../data/simulations/exp_collection , clear
simulate pval = r(pvalue) tau_bind= r(tau_bind) , reps(500) seed(3456)    :  ///
         hyp1 , nobs(`sample_size') means($mean_HM $mean_HF $mean_LM $mean_LM) ///
		 sd($sd_HM $sd_HF $sd_LM $sd_LM) t_binding(`tt' `tt') t_minority(0.01)

count if pval < 0.1
local power = `r(N)' / 500		 
		 
}		 
di "lucas"
	file write lucas  "`sample_size' , `power' , `tt' " _n
		 
		 }
		 file close lucas		 

				 
			*FIGURE 2	 
import delimited "../data/simulations/sample_size_point_estimates.csv", clear 	 

scatter tau sample_size  , xtitle("Sample size") ytitle("Differences in binding treatment") ylab(0(1)7) ///
	note(Notes: Minimum detectable effects for {&alpha} = 0.1 & 1-{&beta} {&ge} 0.8. /*
	*/Effects measured in percentage points)


 graph export ../results/minimum_effects.pdf , replace

 
 