*-------------------------------*
*	Descriptive statistics      *
*-------------------------------*


use ../data/data_ready_202340425 , replace 

drop if mi(komp_)

egen lucas= group(excellent female)
replace lucas= . if cv_fe==3

cdfplot komp_ if cv_fe!=3, by(lucas) xline(78)

egen lucas2 = group(clause female)
replace lucas= . if cv_fe==3
cdfplot komp_ if cv_fe!=3, by(lucas2) xline(78)


 cdfplot komp_ if cv_fe!=3 & excellent == 1, by(female) xline(78) name(gr1, replace) 
 cdfplot komp_ if cv_fe!=3 & excellent == 0, by(female) xline(78) name(gr2, replace) 


*	Randomization success (?)
*---------------------------------------

preserve

bys TOKEN:  gen fobs =  _n == 1
		
tab title      , gen(dtitle)
tab discipline , gen(ddiscipline)
tab part_rec   , gen(dpart)
 
foreach var of varlist dtitle* ddiscipline* dpart* { 
local title : var label `var'
local labels = substr("`title'" , strpos("`title'","=")+2,.)
 
 label var `var' "`labels'"
} 

 

bys treat1 : eststo : estpost summarize fem_respondent phd_year dtitle* ddiscipline* dpart* minutes all_yes no_diff if fobs == 1


*local printto using ../output/randomization.tex 
esttab est1 est2  `printto' , cells((mean(fmt(1 3)) sd(fmt(2)))) label  replace ///
		refcat( ddiscipline1 "Field of study" dtitle1 "Degree" ///
		dpart1 "Experience in recruitment" minutes "Quality of answers" , nolab) ///
		mtitle("Non binding" "Binding") nonumber 
		
		
restore



 
mat results = J(1000, 4 , .)

quiet forvalues i = 1/1000 {
	preserve
  drop if no_diff ==1
capture drop which_order random komp_1 komp_2 komp_diff disc_diff
gen random = runiform()
bys TOKEN (random) : gen which_order = _n		

egen komp_1 = max(komp_*(which_order==3)), by(TOKEN)		
egen komp_2 = max(komp_*(which_order==2)), by(TOKEN)				

gen komp_diff = abs(komp_1 - komp_2)

quiet recode komp_diff (0 = 1 ) (1/4=2) (5/15= 3) (15/. =4) , gen(disc_diff) 
quiet tab disc_diff if which_order ==3 , matcell(lucas) 

mat lucas = lucas /`r(N)' 

restore

mat results[`i' , 1] =  lucas'
}



* Raw differences across CVs
*----------------------------------------------
eststo clear

tab rank, gen(d_rank)
forvalues i = 1/3{
	label var d_rank`i' "`i'"
}

label var komp   "Competences of candidate"
label var invite "Should we invite candidate"


bys excellent : eststo : estpost summarize komp_ invite_  d_rank*

local printto using ../output/tab_valexcellent.tex 
esttab est1 est2  `printto' , cells((mean(fmt(2 3)) sd(fmt(2)))) label  replace ///
		refcat( d_rank1 "Position in the ranking" , nolab) ///
		mtitle("Normal" "Excellent") nonumber 

		
bys female : eststo : estpost summarize komp_ invite_  d_rank*
bys female : eststo : estpost summarize komp_ invite_  d_rank* if treat1==1
bys female : eststo : estpost summarize komp_ invite_  d_rank* if treat1==2

local printto using ../output/tab_outcome_desc.tex 
esttab est3 est4  `printto' , cells((mean(fmt(2 3)) sd(fmt(2)))) label  replace ///
		refcat( d_rank1 "Position in the ranking" , nolab) ///
		posthead("Panel 1: All observations \\" ) ///
		mtitle("Male CV" "Female CV") nonumber  postfoot("") prefoot("")

esttab est5 est6  `printto' , cells((mean(fmt(2 3)) sd(fmt(2)))) label  append ///
		refcat( d_rank1 "Position in the ranking" , nolab) ///
		posthead("[0.5em] Panel 2: Recruitment condition \\" ) ///
		mtitle(none) mlabel(none) eqlabel(none) nonumber prehead("%") prefoot("") postfoot("%")
		
esttab est7 est8  `printto' , cells((mean(fmt(2 3)) sd(fmt(2)))) label  append ///
		refcat( d_rank1 "Position in the ranking" , nolab) ///
		posthead("[0.5em] Panel 3: Hiring condition \\" ) ///
		mtitle(none) mlabel(none) eqlabel(none) nonumber prehead("%") prefoot("") 

ttest komp_             , by(female) unequal				
ttest komp_ if treat1==1, by(female) unequal						
ttest komp_ if treat1==2, by(female) unequal						

ttest invite_             , by(female) unequal				
ttest invite_ if treat1==1, by(female) unequal						
ttest invite_ if treat1==2, by(female) unequal			

	matrix results = J(12 , 5 , .)
    local i = 1
	
quiet foreach feat in excellent female{	
	local ++i
foreach var of varlist komp_ invite_ d_rank* {

			ttest `var' , by(`feat')		unequal
			mat results[`i',1] = r(mu_1), r(sd_1) , r(mu_2) , r(sd_2)  
			
			if inlist("`var'" , "komp_" , "invite_") {
				kwallis `var' , by(`feat')
				mat results[`i',5] =     chi2tail(r(df),r(chi2_adj))	
			}
			
			if "`var'" =="d_rank1" {
				tab rank `feat' , chi
				mat results[`i',5] =     `r(p)'	
			}	
			
			
			local i = `i' +1	
}		

}
			
			
matrix colnames results = "Mean" "SD" "Mean" "SD" "P-value"			
matrix rownames results = "Excellent vs normal CV" "Competences" "Invitation" "Rank first" "Rank second" "Rank third" ///
						 "Male vs Female CV"	"Competences" "Invitation" "Rank first" "Rank second" "Rank third"

local printto using "../output/raw_comparisons.tex"
esttab matrix(results , fmt(2)) `printto' , cells((mean(fmt(2 3)) sd(fmt(2)))) label  replace ///
		refcat( d_rank1 "Position in the ranking" , nolab) ///
	    nonumber nomtitle						
		

*	Double differences
*-------------------------------------------------		

graph bar (mean) komp     , over(female) over(treat1)  ytitle(Competences)  name(gr1, replace) ylab(0(20)85)  
graph bar (mean) invite   , over(female) over(treat1)  ytitle(Invitation)   name(gr2, replace)  ylab(0(0.2)0.85)

		
graph combine gr1 gr2 , name(gr_comb, replace) xsize(7)
graph export "../output/double_diff_raw.pdf"
		