*----------------------------*
*	   More descriptives     *
*----------------------------*


use ../data/data_ready_202340425 , replace 

drop if mi(komp_)
drop fobs

bys TOKEN: gen fobs = _n ==1




**# Differences within subjects

* Evaluation of candidates: excellent
egen komp_EF = max(komp_*(inlist(cvname, "Anny"  , "Barbary")))  , by(TOKEN)		
egen komp_EM = max(komp_*(inlist(cvname, "Adama" , "Bartosza"))) , by(TOKEN)		

* Evaluation of candidates: High quality
egen komp_HF    = sum(komp_*(inlist(cvname, "Justyny"  , "Katarzyny", "Marty", "Pauliny")))  , by(TOKEN)
egen n_cv_women = sum(inlist(cvname, "Justyny"  , "Katarzyny", "Marty", "Pauliny")) , by(TOKEN)
replace komp_HF = komp_HF / n_cv_women
drop n_cv_women

egen komp_HM    = sum(komp_*(inlist(cvname, "Jana" , "Karola", "Marka", "Piotra"))) , by(TOKEN)		
egen n_cv_men   = sum(inlist(cvname, "Jana" , "Karola", "Marka", "Piotra")) , by(TOKEN)
replace komp_HM = komp_HM / n_cv_men
drop n_cv_men


** Distribution of komp: 
*--------------------------

ksmirnov 	komp_ if excellent==1 	, by(female) exact
local pvalue : display %4.3f `r(p_exact)' 

cdfplot komp_ if excellent==1, by(female)  ///
		opt1( lc(green black ) )   ///
	    legend( order(1 "Male CV" 2 "Female CV" )  c(1) pos(11) ring(0))  ///
			note("p-value of Kolmogorov-Smirnov  test:  `pvalue'") 
graph export   ../output/cdf_competences_E_bygender.pdf , replace

ksmirnov 	komp_ if excellent==1 	, by(female) exact
local pvalue : display %4.3f `r(p_exact)' 

cdfplot komp_ if excellent==0, by(female) ///
		opt1( lc(green black) )    ///
	    legend( order(1 "Male CV" 2 "Female CV" )  c(1) pos(11) ring(0))  ///
			note("p-value of Kolmogorov-Smirnov  test:  `pvalue'") 
graph export   ../output/cdf_competences_H_bygender.pdf , replace

** Alternative as a single graph
egen grouping = group(excellent female)
cdfplot komp_ , by(grouping) 


ttest komp_EM == komp_EF if fobs==1
local pvalue : display %4.3f `r(p)' 

twoway (hist komp_ if female==1, color(black%30) bin(25)) ///
	   (hist komp_ if female==0, lcolor(green) fcolor(none) bin(25)) if excellent==1, ///
	    legend( order(1 "Female CV" 2 "Male CV")  c(1) pos(11) ring(0)) ///
		note("p-value of means equality two-sided T-test  for male and female applications: `pvalue'") 
graph export   ../output/competences_E_bygender.pdf , replace
	 
ttest komp_HM == komp_HF if fobs==1
local pvalue : display %4.3f `r(p)' 
twoway (hist komp_ if female==1, color(black%30) bin(25)) ///
	   (hist komp_ if female==0, lcolor(green) fcolor(none) bin(25)) if excellent==0 , ///
	    legend( order(1 "Female CV" 2 "Male CV")  c(1) pos(11) ring(0))  ///
		note("p-value of means equality two-sided T-test  for male and female applications: `pvalue'") 
graph export   ../output/competences_H_bygender.pdf , replace




** Dsitribution of differences
*------------------------------------
		
gen diff_E = komp_EM - komp_EF
gen diff_H = komp_HM - komp_HF

** Raw differences
ksmirnov 	diff_E	if fobs==1	, by(treat1) exact
local pvalue : display %4.3f `r(p_exact)' 
cdfplot 	diff_E	if fobs==1	, by(treat1)  ///
			legend(order(1 "HC condition" 2 "NHC condition" ) c(1) pos(4) ring(0)) ///
			xtitle("Score men - score women" "for candidates designated as Excellent") ///
			xline(2, lcolor(gs12)) xline(-2, lcolor(gs12))  xlab(-100(50)100) ///
			note("p-value of Kolmogorov-Smirnov  test `pvalue'") 
graph export   ../output/diffs_E_gender.pdf , replace

ksmirnov 	diff_H	if fobs==1	, by(treat1) exact
local pvalue : display %4.3f `r(p_exact)' 
cdfplot 	diff_H  if fobs==1	, by(treat1)  ///
			legend(order(1 "HC condition" 2 "NHC condition") c(1) pos(4) ring(0)) ///
			xtitle("Score averaged for men - score averaged for women" "for candidates designated as High Quality") ///
			xline(2, lcolor(gs12)) xline(-2, lcolor(gs12))  xlab(-100(50)100) ///
			note("p-value of Kolmogorov-Smirnov  test `pvalue'")
graph export   ../output/diffs_H_gender.pdf , replace


** Differences conditional on minority status

* These differences do not make sense as they are because minority status refers 
* to a given recruitment, and not to a participant. And our measures of average
* scores for average women / men vary only between individuals. 

egen same_comp	 = sd(n_women) , by(sets)
replace same_comp = cond(same_comp>0 , 0 , 1)


ksmirnov 	diff_E	if fobs==1	, by(one_woman) exact
local pvalue : display %4.3f `r(p_exact)' 
cdfplot 	diff_E	if fobs==1	, by(one_woman)  ///
			legend(order(1 "Female majority" 2 "Female minority" ) c(1) pos(4) ring(0)) ///
			xtitle("Score men - score women" "for candidates designated as Excellent") ///
			xline(2, lcolor(gs12)) xline(-2, lcolor(gs12))  xlab(-100(50)100) ///
			note("p-value of Kolmogorov-Smirnov  test `pvalue'") 
graph export   ../output/diffs_minority_gender.pdf , replace

ksmirnov 	diff_H	if fobs==1	& same_comp ==1 , by(one_woman) exact
local pvalue : display %4.3f `r(p_exact)' 
cdfplot 	diff_H  if fobs==1	& same_comp ==1  , by(one_woman) ///
			legend(order(1 "Female majority" 2 "Female minority") c(1) pos(4) ring(0)) ///
			xtitle("Score averaged for men - score averaged for women" "for candidates designated as High Quality") ///
			xline(2, lcolor(gs12)) xline(-2, lcolor(gs12))  xlab(-100(50)100) ///
			note("p-value of Kolmogorov-Smirnov  test `pvalue'")
graph export   ../output/diffs_majority_gender.pdf , replace


** Tabulation for description in the text
capture drop diff_E_tab
recode diff_E (-100/-3 = -3) (-2/2 = 0 ) (3/100=3) , gen(diff_E_tab)
tab diff_E_tab if fobs == 1

capture drop diff_H_tab
recode diff_H (-100/-2.01 = -3) (-2/2 = 0 ) (2.01/100=3) , gen(diff_H_tab)
tab diff_H_tab if fobs == 1

tab diff_E_tab one_woman if fobs == 1 
tab diff_H_tab one_woman if fobs == 1



** Differences conditional on the resume
*------------------------------------------

* Variation is only between subjects

** ACROSS GENDERS
		label def sex 0 "Male version" 1 "Female version" ,modify

* Perceived competence 
cibar komp_ if cv_fe!=3, over(female cv_fe)  barcol(green%30 black%30 ) ciopts(lcolor(black)) ///
				graphopts( ytitle("Perceived competence" "by gender")  name(gr1, replace) ///
				ylab(0(15)90) xtitle(Profile number)) 
				
graph export   ../output/differences_bars_komp_byfem.pdf , replace
 				
* Probability of invitation
cibar invite if cv_fe!=3, over(female cv_fe ) barcol(green%30 black%30 )   ciopts(lcolor(black)) ///
				graphopts( ytitle("Probability of invitation" "by gender") ///
				name(gr2, replace) ylab(0(0.25)1) xtitle(Profile number)) 

graph export   ../output/differences_bars_invite_byfem.pdf , replace

* Do we want them together? 				
grc1leg gr1 gr2		, name(gr3 , replace)
graph di gr3, xsize(6)		
graph export   ../output/differences_bars_byfem.pdf , replace
 

** ACROSS TREATMENT CONDITIONS
label def treats 1 "No Hiring commitment" 2 "Hiring commitment" ,modify

cibar komp_ , over(treat1 cv_fe)  barcol(green%20 purple%30) ciopts(lcolor(black)) ///
				graphopts( ytitle("Perceived competence" "by treatment condition")  name(gr4, replace) ///
				ylab(0(15)90) xtitle(Profile number)) 

cibar invite , over(treat1 cv_fe)  barcol(green%20 purple%30) ciopts(lcolor(black)) ///
				graphopts( ytitle("Probability of invitation" "by treatment condition") ///
				name(gr5, replace) ylab(0(0.25)1) xtitle(Profile number)) 

grc1leg gr4 gr5		, name(gr6, replace)
graph di gr6, xsize(6)		
				
graph export   ../output/differences_bars_bytreat1.pdf , replace
 

 graph box  komp_ if cv_fe!=3, over(female ) by(cv_fe)   
				
 
** Are differences between men and women statistically significant 
*---------------------------------------------------------------------

* Create matrix with outputs for coefplot
foreach l in r i {
	foreach g in 1 2 all{
		mat `l'_`g' = J(4,6,.)
		mat colnames `l'_`g' =1 2 4  5 6 7
	}	
}

local i = 0 
quiet forvalues cv = 1/7{
	if `cv' == 3 continue
	di "`cv'"
	local i = `i'+1
	
	foreach treat in 1 2 {
		
	ttest komp_ if cv_fe ==`cv' & treat1==`treat'  , by(female) unequal
	
	mat r_`treat'[1, `i' ] = r(mu_1) - r(mu_2) \	r(se)
	mat r_`treat'[3, `i' ] =  r_`treat'[1, `i'] - 1.96*r_`treat'[2, `i']
	mat r_`treat'[4, `i' ] =  r_`treat'[1, `i'] + 1.96*r_`treat'[2, `i']


	ttest invite if cv_fe ==`cv' & treat1==`treat'    , by(female) unequal
	
	mat i_`treat'[1, `i' ] = r(mu_1) - r(mu_2) \	r(se)
	mat i_`treat'[3, `i' ] =  i_`treat'[1, `i' ] - 1.96 * i_`treat'[2, `i' ]
	mat i_`treat'[4, `i' ] =  i_`treat'[1, `i' ] + 1.96 * i_`treat'[2, `i' ]
	}
	
	ttest komp_ if cv_fe ==`cv' , by(female) unequal
	
	mat r_all[1, `i' ] = r(mu_1) - r(mu_2) \	r(se)
	mat r_all[3, `i' ] =  r_all[1, `i'] - 1.96*r_all[2, `i']
	mat r_all[4, `i' ] =  r_all[1, `i'] + 1.96*r_all[2, `i']
	
	ttest invite if cv_fe ==`cv'    , by(female) unequal
	
	mat i_all[1, `i' ] = r(mu_1) - r(mu_2) \	r(se)
	mat i_all[3, `i' ] =  i_all[1, `i'] - 1.96 * i_all[2, `i']
	mat i_all[4, `i' ] =  i_all[1, `i'] + 1.96 * i_all[2, `i']
}


local opts   `"  vertical xtitle("Profile") ytitle("Difference in averages" "(men - women)") yline(0)"'
coefplot (matrix(r_1) , ci((3 4)) ) (matrix(r_2) , ci((3 4)) ) ,`opts'   ///
		 legend(order(2 "HC condition " 4 "NHC condition"))  ///
	     name(gr1, replace)  // 	title("Perceived competences")
graph export ../output/mean_dif_komp.pdf, replace
		
		
coefplot (matrix(i_1) , ci((3 4)) ) (matrix(i_2) , ci((3 4)) ) ,`opts'   ///
		legend(order(2 "HC condition " 4 "NHC condition"))  ///
		  name(gr2, replace)  //title("Probability of invitation")
graph export ../output/mean_dif_invitation.pdf, replace
				

local opts   `"  vertical xtitle("Profile") ytitle("Difference in averages" "(men - women)") yline(0)"'
coefplot matrix(r_all) , ci((3 4)) `opts'  title("Perceived competences")       name(gr1, replace)  
coefplot matrix(i_all) , ci((3 4)) `opts'  title("Invitation to an interview")  name(gr2, replace)   

graph combine gr1 gr2 , c(1)
graph export ../output/all_differences.pdf , replace

exit
*--------------------------------------------------------------------------------*

* OLD CODE BELOW: CIBAR without BARS :) 

mat komps = J(3,7, .)
mat colnames komps   = 1 2 3 4 5 6 7

mat invites= J(3,7, .)
mat colnames invites = 1 2 3 4 5 6 7

quiet forvalues cv = 1/7 {
mean komp_  if cv_fe == `cv'
mat komps[1 , `cv'   ] = el(r(table) ,1,1) \  el(r(table) ,5,1) \ el(r(table) ,6,1)  

mean invite  if cv_fe == `cv'
mat invites[1, `cv'  ] = el(r(table) ,1,1) \  el(r(table) ,5,1) \ el(r(table) ,6,1)  

}



sum komp_ 
local means =`r(mean)'
coefplot matrix(komps) , ci((2 3)) `opts' title("Perceived competence by CV") name(gr1, replace) ///
           yline(`means') vertical xtitle("CV identificator")

sum invite 
local means =`r(mean)'
coefplot matrix(invites) , ci((2 3)) `opts' title("Invite by CV") name(gr2, replace) ///
		vertical yline(`means') xtitle("CV identificator")
		
		
graph combine gr1 gr2, c(1)		
graph export ../output/differences_across_CVS.pdf , replace

exit
