*----------------------------*
*	Initial regressions      *
*----------------------------*


use ../data/data_ready_202340425 , replace 


drop if mi(komp_)


label define treat1 1 "T = HC" 2 "T = NHC"
label val treat1 treat1
label def cvfe 1 "1" 2 "2" 3 "3" 4 "4" 5 "5" 6 "6" 7 "7"
label val cv_fe cvfe

**# Setting the different Hypotheses 
*-------------------------------------

*(1) Female candidates receive lower rating in BINDING
global mainx1  "i.female##ib2.treat1 "

*(2) Female candidates receive lower rating in MINORITY 
global mainx2  "i.female##i.min_candidate  "

*(3) Female candidates receive lower rating in MINORITY & BINDING
global mainx3  "i.female##i.min_candidate##ib2.treat1"

*(4) Female candidates receive lower rating in MINORITY 
global mainx4  "i.female##i.excellent "

*(5) Female candidates receive lower rating in MINORITY & BINDING
global mainx5  "i.female##i.excellent##ib2.treat1"



**# Estimations
*----------------------------------------

** Regression characteristics
global x_resp "i.fem_respondent phd_year i.title i.part_rec i.discipline "

egen group = group(TOKEN recruitment)
global stderr "vce(cluster group)"

quiet foreach yvar in komp_ invite_ {
	
	local y   = substr("`yvar'" , 1, 1)
	
	forvalues h  = 1/5{
		di "`h'"
		if `h' < 4 {
 
			eststo h`h'_`y'_1: reg `yvar'   ${mainx`h'}  i.cv_fe          if cv_fe !=3 , $stderr  
			eststo h`h'_`y'_2: reg `yvar'   ${mainx`h'}  i.cv_fe  $x_resp if cv_fe !=3 , $stderr 
		}
		if `h'>3{
			eststo h`h'_`y'_1: reg `yvar'   ${mainx`h'}           if cv_fe !=3 , $stderr
			eststo h`h'_`y'_2: reg `yvar'   ${mainx`h'}  $x_resp  if cv_fe !=3 , $stderr	
		}
		
		if inlist(`h' , 1, 3, 5) {
		
			* Sample sizes
			mat aux= r(table) 
			mat b  = aux["b" , "1.female#1.treat1"]
	      	mat se = aux["se" , "1.female#1.treat1"]
			scalar p1 = aux["pvalue" , "1.female#1.treat1"]
							
			local denominator = invnormal(0.95) * se[1,1] *sqrt(e(N)-e(rank))  
			scalar ssize = ceil( 1/(b[1,1] / `denominator' )^2 + e(rank) )
			
			estadd scalar p1 
			estadd scalar ssize 
	
			* p value for whether there is an effect on woman in hiring condition
			test 1.female#1.treat1 + 1.treat1 = 0 
					local Fstat r(F)
					local df_r =  r(df_r)+ 1
					
			estadd scalar pvalue = r(p) 
		
			foreach ssize in 20000 10000 5000 3000 1500{
					local ratio = `ssize' / `df_r'
					local pval = 1 - F(1, `ssize' - 1, `Fstat'*`ratio')
					di " p :`pval'"
					if `pval' > 0.1 {
						local sample `ssize' 
						continue, break
						}

			}
			estadd scalar samples = `sample'/2 
			 
			
		}

	}
}
 

**# Making a nice-looking table
*--------------------------------------------------------

label define min_cand 0 "empy" 1 "Context", modify
label val min_cand min_cand

global stats stat(N  r2 p1 ssize pvalue samples , label("Observations" "R-squared" "P-value" "sample size" "[1em]H0: $\hat{\beta}\_{T} + \hat{\beta}\_{G,T}=0$ \\ P-value" "Sample needed to reject H0")) 
global opts1 se star(* .10 ** .05 *** .01)  $stats
global nopes noomit nobase nonumbers nonotes


local coltitles  "Eq \eqref{eq:main}  &   \multicolumn{2}{c}{Context: minority}   &  \multicolumn{2}{c}{Context: quality}"

local print_to using "../output/initial_results_b.tex"
esttab h?_k_2  h?_i_2    `print_to' , label  ///
        keep(*female* *treat1* *min_cand* )  $opts1 $nopes  replace ///
		prehead("{\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" ///
		"\begin{tabular}{l*{10}{c}}" "\hline\hline" ///
		"& \multicolumn{5}{c}{Competences}&\multicolumn{5}{c}{Invitation}\\" ///
		"&  `coltitles' & `coltitles' \\") ///
		indicate("Resume FE = 2.cv_fe" "Respondent characteristics =phd_year" ) ///
		mlab( (1a) (2a) (3a) (4a) (5a) (1b) (2b) (3b) (4b) (5b) )   ///
		rename(1.excellent 1.min_candidate 1.female#1.excellent 1.female#1.min_candidate ///
		1.excellent#1.treat1 1.min_candidate#1.treat1  /// 
		1.female#1.excellent#1.treat1 1.female#1.min_candidate#1.treat1 )

		
global stats stat(N  r2 , label("Observations" "R-squared" )) 
global opts1 se star(* .10 ** .05 *** .01)  $stats
global nopes noomit nobase nonumbers nonotes
local coltitles  "Eq \eqref{eq:main}  &   \multicolumn{2}{c}{Context: minority}   &  \multicolumn{2}{c}{Context: quality}"
	
local print_to using "../output/app_full_initial.tex"
esttab h?_k_2  h?_i_2  `print_to' , label    ///
        order(*female* *treat1* *min_cand* *excellent*) $opts1 $nopes  replace ///
		prehead("{\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" ///
		"\begin{tabular}{l*{10}{c}}" "\hline\hline" ///
		"& \multicolumn{5}{c}{Competences}&\multicolumn{5}{c}{Invitation}\\" ///
		"&  `coltitles' & `coltitles' \\") ///
		refcat(2.cv_fe "Profile fixed effects" fem_respondent "Respondent characteristics" ///
		2.title  "Academic degree" 2.part_rec "Experience in recruitment" ///
		2.discipline "Field of studies" , nolabel)
		
		
		exit
		
**#   Power calculations
*----------------------------------------------


matrix results = J(6,4 , 99)
mat colnames results = beta se tstat Power
mat rownames results = h1_k_2  h2_k_2  h3_k_2  h1_i_2 h2_i_2  h3_i_2

local i = 1

foreach var in  h1_k_2  h2_k_2  h3_k_2  h1_i_2 h2_i_2  h3_i_2 {
quiet  estimates table `var'  , se   keep(1.female#1.treat1)
mat aux = r(coef)

matrix results[`i',1] = aux[1,1]
matrix results[`i',2] = sqrt(aux[1,2])
matrix results[`i',3] = results[`i',1] / results[`i',2]
local pabove = 1-normal(invnormal(0.95) - results[`i',3])
local pbelow =   normal(invnormal(0.05) - results[`i',3])
matrix results[`i',4] =   `pabove'+  `pbelow'

local ++i
}

 
local print_to using ../output/power_calculations.tex
estout matrix(results, fmt(3)) `print_to' , replace ///
			prehead("\begin{tabular}{l|cccc}" "\hline \hline") ///
			posthead("\hline") postfoot("\hline \hline" "\end{tabular}")  ///
			refcat(h1_k_2 "Competences" h1_i_2 "Invitation" , nolabel) sty(tex) ///
			varlabels(h1_k_2 "Model 1" h2_k_2 "Model 2" h3_k_2 "Model 3" ///
			h1_i_2 "Model 1"  h2_i_2  "Model 2"  h3_i_2 "Model 3")
	

	
	
**#   Sample sizes
*----------------------------------------------


matrix s_size = J(6,4 , 99)
mat colnames results = beta se denominator s_size
mat rownames results = h1_k_2  h2_k_2  h3_k_2  h1_i_2 h2_i_2  h3_i_2

local i = 1

foreach var in  h1_k_2  h2_k_2  h3_k_2  h1_i_2 h2_i_2  h3_i_2 {
estimates restore `var'
  estimates table `var'  , se   keep(1.female#1.treat1) stat(n)
mat aux = r(coef)

matrix s_size[`i',1] = aux[1,1]			
matrix s_size[`i',2] = sqrt(aux[1,2])
matrix s_size[`i',3] = invnormal(0.95) * sqrt(aux[1,2]) *sqrt(e(N)-e(rank))  
matrix s_size[`i',4] = 1/(aux[1,1] / s_size[`i',3] )^2 + e(rank)

local ++i
}

 
local print_to using ../output/sample_sizes.tex
estout matrix(s_size, fmt(3)) `print_to' , replace ///
			prehead("\begin{tabular}{l|cccc}" "\hline \hline") ///
			posthead("\hline") postfoot("\hline \hline" "\end{tabular}")  ///
			refcat(h1_k_2 "Competences" h1_i_2 "Invitation" , nolabel) sty(tex) ///
			varlabels(h1_k_2 "Model 1" h2_k_2 "Model 2" h3_k_2 "Model 3" ///
			h1_i_2 "Model 1"  h2_i_2  "Model 2"  h3_i_2 "Model 3")
	