*----------------------------*
*	Initial regressions      *
*----------------------------*


use ../data/data_ready_202340425 , replace 


drop if mi(komp_)
egen group = group(TOKEN recruitment)

label define Minority 1 "Context" 0 "empty", modify
label val min_candidate Minority

label define treats 1 "HC" 2 "NHC" , modify
 


**# Regression characteristics
*--------------------------------------------------------

global x_resp "phd_year i.title i.part_rec i.discipline i.fem_respondent"
global stderr "vce(cluster group)"

* Hypothesis 1: Female candidates receive lower rating in HC
global mainx1  "i.female##ib2.treat1"

* Hypothesis 2: Female candidates receive lower rating when it is a male position
global mainx2  "i.female##i.min_candidate##ib2.treat1"


* Hypothesis 3: Three-way interaction: Gender # Excellent # Binding 
global mainx3   "i.female##i.excellent##ib2.treat1"


**#  Focus on participants who spotted a difference
*----------------------------------------------------------

global ifqlty "all_yes != 1 & diff>0 "

foreach yvar in komp invite {
 
	local y   = substr("`yvar'" , 1, 1)
 	local ifs "$ifqlty & cv_fe!=3"
	
	forvalues h  = 1/3{
		eststo h`h'_`y'_1: reg `yvar'  i.cv_fe  ${mainx`h'}          if `ifs' , $stderr  
		eststo h`h'_`y'_2: reg `yvar'  i.cv_fe  ${mainx`h'}  $x_resp if `ifs' , $stderr 

	}

}
 
 
 **  Making a nice-looking table

global opts1 se star(* .10 ** .05 *** .01) stat(N r2 , label("Observations" "R-squared"))
global nopes noomit nobase nonumbers nonotes

local print_to using "../output/quality_results.tex"
esttab h?_k_2  h?_i_2  `print_to' , ///
			keep(*female* *treat1* *min_cand*  ) $opts1 $nopes  replace ///
			label  indicate("Resume FE = 2.cv_fe" "Respondent characteristics =phd_year" ) ///
			mgroups( "Competences" "Invitation" , pattern(1 0 0 1 0 0) ///
			span prefix(\multicolumn{@span}{c}{) suffix(}))  ///
			mlab( (1) (2) (3) (1) (2) (3) )   ///
			rename(1.female#1.excellent 1.female#1.min_candidate ///
		    1.excellent#1.treat1 1.min_candidate#1.treat1  /// 
		    1.female#1.excellent#1.treat1 1.female#1.min_candidate#1.treat1 )

			
**# Focusing on average time
*--------------------------------------

foreach yvar in komp invite {
 
	local y   = substr("`yvar'" , 1, 1)
    local ifs  "cv_fe!=3 & inrange(minutes,5,11)"
	
	forvalues h  = 1/3{
		eststo h`h'_`y'_1: reg `yvar'  i.cv_fe  ${mainx`h'}          if `ifs' , $stderr  
		eststo h`h'_`y'_2: reg `yvar'  i.cv_fe  ${mainx`h'}  $x_resp if `ifs' , $stderr 

	}

}


global opts1 se star(* .10 ** .05 *** .01) stat(N r2 , label("Observations" "R-squared"))
global nopes noomit nobase nonumbers nonotes

local print_to using "../output/attention_results.tex"
esttab h?_k_2  h?_i_2 `print_to' , ///
		keep(*female* *treat1* *min_cand* ) $opts1 $nopes  replace ///
		label  indicate("Resume FE = 2.cv_fe" "Respondent characteristics =phd_year" ) ///
		mgroups( "Competences" "Invitation" , pattern(1 0 0 1 0 0) ///
		span prefix(\multicolumn{@span}{c}{) suffix(}))  ///
		mlab( (1) (2) (3) (1) (2) (3) )   ///
		rename(1.female#1.excellent 1.female#1.min_candidate ///
		       1.excellent#1.treat1 1.min_candidate#1.treat1  /// 
		       1.female#1.excellent#1.treat1 1.female#1.min_candidate#1.treat1 )
			


**# Consistency check: higher rated candidates should be invited if lower are invited
*------------------------------------------------------------------------------------

bys TOKEN recruitment (komp_) : gen which_order = _n		


forvalues i = 1/3 {
capture drop invite_`i'
egen invite_`i' = max(invite_*(which_order==`i')) , by(TOKEN recruitment)

capture drop komp_`i'
egen komp_`i'   = max(komp_*  (which_order==`i')) , by(TOKEN recruitment)
}			

** Cases when people invite lower rated candidates, but not higher rated
count if invite_1 == 1 & (invite_2==0 & invite_3 ==0) & which_order ==3
list TOKEN komp_ invite*  female cvname recruitment if invite_1 == 1 & (invite_2==0 & invite_3 ==0)  , sepby(TOKEN)

count if invite_2 == 1 & invite_3 ==0                 & which_order ==3			
list  komp_ invite* if invite_2 ==1 & invite_3 == 0


** Cases when experts rated candidates equally, but only one is accepted
count if (komp_1 == komp_2 & invite_1 != invite_2) | ///
         (komp_1 == komp_3 & invite_1 != invite_3) | ///
		 (komp_3 == komp_2 & invite_3 != invite_2) & which_order ==3
di 30/2052 
 
list TOKEN komp_ invite*    treat1 cvname recruitment ///
    if   (komp_1 == komp_2 & invite_1 != invite_2) | ///
         (komp_1 == komp_3 & invite_1 != invite_3) | ///
		 (komp_3 == komp_2 & invite_3 != invite_2) , sepby(TOKEN)

 
tab which_order rank  if (komp_3 != komp_2) & (komp_2!= komp_1)
tab which_order rank  if (komp_3 != komp_2)  


count if rank!= (4-which_order) & (komp_3 != komp_2) & (komp_2!= komp_1)
 
 


**#        Heterogeneity analysis
*-----------------------------------------
	
	
** Results by gender
eststo clear

foreach sex in m f{
	
** All respondents 	
local xval = cond("`sex'" =="f" , 1, 0)
local ifs   "cv_fe!=3 & fem_respondent==`xval'"

local yvar komp
eststo h1_k`sex'_1all: reg `yvar'   $mainx1  i.cv_fe          if `ifs', $stderr  
eststo h1_k`sex'_2all: reg `yvar'   $mainx1  i.cv_fe  $x_resp if `ifs' , $stderr 


local yvar invite
eststo h1_i`sex'_1all: reg `yvar'   $mainx1  i.cv_fe           if `ifs' ,  $stderr
eststo h1_i`sex'_2all: reg `yvar'   $mainx1  i.cv_fe  $x_resp  if `ifs' ,   $stderr

** Quality sample
local ifs   "cv_fe!=3 & all_yes != 1 & diff>0 & fem_respondent==`xval'"

local yvar komp
eststo h1_k`sex'_1q: reg `yvar'   $mainx1  i.cv_fe          if `ifs', $stderr  
eststo h1_k`sex'_2q: reg `yvar'   $mainx1  i.cv_fe  $x_resp if `ifs' , $stderr 


local yvar invite
eststo h1_i`sex'_1q: reg `yvar'   $mainx1  i.cv_fe           if `ifs' ,  $stderr
eststo h1_i`sex'_2q: reg `yvar'   $mainx1  i.cv_fe  $x_resp  if `ifs' ,   $stderr


} 

local print_to using "../output/results_by_gender.tex"

esttab h1_k*_2all h1_i*_2all `print_to' , keep(*female* *treat1*)    ///
			 $opts1 $nopes  replace ///
			label  indicate("Resume FE = 2.cv_fe" "Respondent characteristics =phd_year" ) ///
			mgroups( "Competences" "Invitation" , pattern(1 0  1 0 ) ///
			span prefix(\multicolumn{@span}{c}{) suffix(}))  ///
			mlab( (Men) (Women) (Men) (Women) ) 
 
 
 
**#     Results by Discipline
*---------------------------------

clonevar field = discipline
replace field = 1 if discipline ==8
replace field = 3 if discipline == 4


global x_resp "phd_year i.title i.part_rec  i.fem_respondent"

eststo clear
global mainx  "i.female##ib2.treat1 "
levelsof field, local(fields) 

quiet foreach ff in `fields'{
 
** All respondents 	
local ifs   "cv_fe!=3 & field==`ff'"

local yvar komp
eststo h1_k`ff'_1all: reg `yvar'   $mainx  i.cv_fe          if `ifs', $stderr  
eststo h1_k`ff'_2all: reg `yvar'   $mainx  i.cv_fe  $x_resp if `ifs' , $stderr 


local yvar invite
eststo h1_i`ff'_1all: reg `yvar'   $mainx  i.cv_fe           if `ifs' ,  $stderr
eststo h1_i`ff'_2all: reg `yvar'   $mainx  i.cv_fe  $x_resp  if `ifs' ,   $stderr

** Quality sample
local ifs   "cv_fe!=3 & field==`ff' & all_yes != 1 & diff>0"

local yvar komp
eststo h1_k`ff'_1q: reg `yvar'   $mainx  i.cv_fe          if `ifs', $stderr  
eststo h1_k`ff'_2q: reg `yvar'   $mainx  i.cv_fe  $x_resp if `ifs' , $stderr 


local yvar invite
eststo h1_i`ff'_1q: reg `yvar'   $mainx  i.cv_fe           if `ifs' ,  $stderr
eststo h1_i`ff'_2q: reg `yvar'   $mainx  i.cv_fe  $x_resp  if `ifs' ,   $stderr


} 

global opts1 se star(* .10 ** .05 *** .01) stat(r2 , label("R-squared"))
local print_to using "../output/results_by_discipline.tex"

esttab h1_k*_2all  `print_to' , keep(*female* *treat1*)    ///
			  $opts1 $nopes  replace ///
			label   ///
			mlab( "Humanities" "Social Sciences"  "Natural Sciences"   ///
			"Engineering and technical" "Agricultural sciences" "Medical and health sciences"  ) ///
			posthead("\hline""Panel 1: Perceived competences \\ [0.5em]") ///
			prefoot("%") postfoot("%")

esttab h1_i*_2all  `print_to' , keep(*female* *treat1*)    ///
			  $opts1 $nopes  append ///
			label mlab(none)  ///
			prehead("%") ///
			posthead("[1.5em]Panel 2: Invitation\\ [0.5em] ") ///
			prefoot("%") postfoot("%")			

esttab h1_i*_2all  `print_to' , drop (*)    ///
			$nopes  append ///
			label mlab(none) indicate("Resume FE = 2.cv_fe" "Respondent characteristics =phd_year" ) ///
			prehead("%") posthead("%")  stats() ///
			prefoot("%") postfoot("\hline \hline" "\end{tabular}")			
						
coefplot h1_k*_2all , keep(1.female) xline(0) level(90) 
coefplot h1_k*_2all , keep(1.female#1.treat1) xline(0) level(90) 
 
 
**#  Non-standardized analysis 
*-------------------------------------------------------------

global mainx min_candidate##ib2.treat1##i.female 

reg komp  $mainx  i.cv_fe             , $stderr 
margins r.min_candidate@female@treat1 , level(90)


reg invite  $mainx  i.cv_fe             , $stderr 
margins  female#treat1 , level(95) at(min_candidate =0)


egen id = group(TOKEN recruitment)
gen highest_rank = rank==1 

clogit highest_rank i.female##ib2.treat1 min_candidate  komp   if all_yes ==1 , group(id)

rologit rank i.female##ib2.treat1##min_candidate    if all_yes ==1 & recruitment ==1 , group(id)
rologit rank i.female##ib2.treat1##min_candidate    if all_yes ==1 & recruitment ==2 , group(id)

rologit rank i.female##ib2.treat1##min_candidate    if $ifqlty & recruitment ==1 , group(id)
rologit rank i.female##ib2.treat1##min_candidate    if $ifqlty & recruitment ==2 , group(id)


rologit rank (i.female##ib2.treat1##min_candidate)##recruitment    if $ifqlty  , group(id)



logit highest_rank female##treat1##min_candidate i.cv_fe if $ifqlty 
reg rank  female##treat1##min_candidate i.cv_fe  if all_yes ==1