*----------------------------*
*	Alternative samples      *
*----------------------------*


use ../data/data_ready_202340425 , replace 

drop if mi(komp_)
egen group = group(TOKEN recruitment)


**# Restricting sample to exclude people who show inconsistent answers
*-----------------------------------------------------------------------

** Defining inconsistencies
capture drop rank_komp
bys TOKEN recruitment (komp_) : gen rank_komp= 4 - _n
replace rank_komp = rank_komp[_n-1] if TOKEN ==TOKEN[_n-1] & ///
                            recruitment==recruitment[_n-1] & ///
							komp_==komp_[_n-1]  

							
gen inconsistent = rank_komp != rank_

egen any_inconsistent = max(inconsistent) , by(TOKEN) 

** Main regressions
global x_resp   "phd_year i.title i.part_rec i.discipline i.fem_respondent"
global ifsample "any_inconsistent == 0 & inrange(minutes, 5 ,45) "
global stderr "vce(cluster group)"



global mainh1  "i.female##ib2.treat1 "
global mainh2  "i.female##ib2.treat1##i.min_candidate"
global mainh3  "i.female##excellent##ib2.treat1" 

quiet foreach yvar in komp_ invite_ {

	local y   = substr("`yvar'" , 1, 1)
 	local ifs "$ifsample & cv_fe!=3"
	
	eststo h1_`y': reg `yvar'   $mainh1  i.cv_fe   $x_resp  if `ifs' , $stderr 
	eststo h2_`y': reg `yvar'   $mainh2  i.cv_fe   $x_resp  if `ifs' , $stderr
	eststo h3_`y': reg `yvar'   $mainh3  i.cv_fe   $x_resp  if `ifs' , $stderr
}



**# Restricting sample to people who are in social sciences / humanities
*-----------------------------------------------------------------------

global x_resp      "phd_year i.title i.part_rec i.discipline i.fem_respondent"
global ifsample    "inlist(discipline, 1, 2)"
global stderr      "vce(cluster TOKEN)"


global mainh1  "i.female##ib2.treat1 "
global mainh2  "i.female##ib2.treat1##i.min_candidate"
global mainh3  "i.female##ib2.treat1##excellent" 

quiet foreach yvar in komp_ invite_ {

	local y   = substr("`yvar'" , 1, 1)
 	local ifs "$ifsample & cv_fe!=3"
	
	eststo h1_`y': reg `yvar'   $mainh1  i.cv_fe   $x_resp  if `ifs', $stderr 
	eststo h2_`y': reg `yvar'   $mainh2  i.cv_fe   $x_resp  if `ifs' , $stderr
	eststo h3_`y': reg `yvar'   $mainh3  i.cv_fe   $x_resp  if `ifs' , $stderr
}



**# Restricting sample to people who provided email address
*-----------------------------------------------------------------------

global x_resp      "phd_year i.title i.part_rec i.discipline i.fem_respondent"
global ifsample    "provided_email ==1"
global stderr      "vce(cluster TOKEN)"


global mainh1  "i.female##ib2.treat1 "
global mainh2  "i.female##ib2.treat1##i.min_candidate"
global mainh3  "i.female##ib2.treat1##excellent" 

quiet foreach yvar in komp_ invite_ {
	
	local y   = substr("`yvar'" , 1, 1)
	local ifs "$ifsample & cv_fe!=3"
	
	eststo h1_`y': reg `yvar'   $mainh1  i.cv_fe   $x_resp  if `ifs', $stderr 
	eststo h2_`y': reg `yvar'   $mainh2  i.cv_fe   $x_resp  if `ifs' , $stderr
	eststo h3_`y': reg `yvar'   $mainh3  i.cv_fe   $x_resp  if `ifs' , $stderr
}


**# Estimating parameters separate for two recruitments
*-----------------------------------------------------------------------

global x_resp      "phd_year i.title i.part_rec i.discipline i.fem_respondent"
global stderr      "vce(cluster TOKEN)"


global mainh1  "i.female##ib2.treat1 "
global mainh2  "i.female##ib2.treat1##i.min_candidate"
global mainh3  "i.female##ib2.treat1##excellent" 


quiet foreach yvar in komp_ invite_ {
	
	local y   = substr("`yvar'" , 1, 1)
	
	foreach r in 1 2{
		
		local ifs "recruitment == `r' & cv_fe!=3"
		
		eststo h1_`y'_`r': reg `yvar'   $mainh1  i.cv_fe   $x_resp  if `ifs', $stderr 
		eststo h2_`y'_`r': reg `yvar'   $mainh2  i.cv_fe   $x_resp  if `ifs' , $stderr
		eststo h3_`y'_`r': reg `yvar'   $mainh3  i.cv_fe   $x_resp  if `ifs' , $stderr
	}
}