*-----------------------------------------------*
*	   Alternative estimation procedures        *
*-----------------------------------------------*

use ../data/data_ready_202340425 , replace 

drop if mi(komp_)

** Create variable with first differences
*-------------------------------------------
egen komp_a = max(komp_*(cv_fe==1)) , by(TOKEN)
egen komp_b = max(komp_*(cv_fe==2)) , by(TOKEN)
gen komp_dif  = komp_a - komp_b


eststo clear
global x_resp   "phd_year i.title i.part_rec i.discipline i.fem_respondent"
global stderr   "vce(cluster TOKEN)"


global mainh1  "i.female##ib2.treat1 "

local yvar komp_ 
eststo h1_k_fe: reg komp_   $mainh1  i.cv_fe  $x_resp  if cv_fe !=3  , $stderr  a(TOKEN)
eststo h1_k_fd: reg komp_dif $mainh1  $x_resp          if cv_fe== 1 , $stderr  
eststo h1_k_to: tobit komp_  $mainh1  i.cv_fe  $x_resp  if cv_fe !=3   , $stderr  ul(100) ll(0)


global opts1 se star(* .10 ** .05 *** .01) stat(N r2 , label("Observations" "R-squared"))
global nopes noomit nobase nonumbers nonotes

local print_to using "../output/fe_komp.tex"
esttab h1_k_fe  h1_k_fd  h1_k_to  `print_to' , ///
        keep(*female* *treat1* ) order(1.female 1.treat1) $opts1 $nopes  replace ///
		label  indicate("Resume FE = 2.cv_fe" "Respondent characteristics =phd_year" ) ///
		mlabel("FE" "FD" "Tobit")
		
		///
		mgroups( "Competences" "Invitation" , pattern(1 0 0 1 0 0) ///
		span prefix(\multicolumn{@span}{c}{) suffix(}))  ///
		mlab( (1) (2) (3) (1) (2) (3) )   

		
local yvar komp_ 
eststo h1_k_2: reg `yvar'   $mainh1  i.cv_fe  $x_resp  if cv_fe !=3 , $stderr 
		
		


**#  Relevant pairwise comparisons
*------------------------------------------

eststo clear
drop female_minority n_women   
reshape wide komp_ invite_ rank_ female excellent recruitment min_candidate cvname komp_fe, i(TOKEN) j(cv_fe)

gen first_dif = komp_1 - komp_2
reg first_dif female1##ib2.treat1   , $stderr

drop first_dif_r
gen first_dif_r = rank_1 < rank_2  if !mi(rank_1, rank_2) 
reg first_dif_r female1##ib2.treat1 $x_resp  


gen second_dif_r2 = rank_2 - rank_3
reg second_dif_r2 female1##ib2.treat1 min_candidate1 

* no difference here -- invite both or neither
drop third_difr 
gen third_difr = rank_3 - rank_6 <0  if !mi(rank_3, rank_6)
reg third_difr female6##ib2.treat1  $x_resp , vce(hc3)

