*--------------------------------------------------------------*
*     What differences can we expect between candidate
*--------------------------------------------------------------*


use ../data/data_ready_202340425 , replace 

drop if mi(komp_)

set seed 20240703



**# Linear regression model for invite using komp_
*--------------------------------------------------

** Regression characteristics
global x_resp "i.fem_respondent phd_year i.title i.part_rec i.discipline "

egen group = group(TOKEN recruitment)
global stderr "vce(cluster group)"

eststo mod_all: reg invite komp_  $mainx  i.cv_fe  $x_resp if cv_fe !=3 , $stderr
eststo mod_fem: reg invite komp_  $mainx  i.cv_fe  $x_resp if cv_fe !=3 & female ==1 , $stderr
eststo mod_men: reg invite komp_  $mainx  i.cv_fe  $x_resp if cv_fe !=3 & female ==0, $stderr

global opts1 se star(* .10 ** .05 *** .01) stat(N r2 , label("Observations" "R-squared"))
global nopes noomit nobase nonumbers nonotes

local print_to using "../output/reg_komp.tex"
esttab mod_all mod_fem mod_men    `print_to' , ///
        keep(*komp*) $opts1 $nopes  replace ///
		label  indicate("Resume FE = 2.cv_fe" "Respondent characteristics =phd_year" )  ///
		mlab( All Women Men )   
		



**#  Distribution of differences
*------------------------------------------

* Differences between two top candidates
bys TOKEN recruitment (komp_) : gen which_order = _n		
egen komp_1 = max(komp_*(which_order==3)), by(recruitment TOKEN)		
egen komp_2 = max(komp_*(which_order==2)), by(recruitment TOKEN)				
gen top2_diff = komp_1 - komp_2 

* Differences between two random candidates
gen random_comp = runiform()
bys TOKEN recruitment (random_comp) : gen rand_order = _n		
egen komp_1r = max(komp_*(rand_order==3)), by(recruitment TOKEN)		
egen komp_2r = max(komp_*(rand_order==2)), by(recruitment TOKEN)				
gen rand_diff = abs(komp_1r - komp_2r)  


* Differences between two random assessments
gen random_between = runiform()
sort random_between
gen rand_group = floor((_n+1)/2)
bys rand_group (komp_) : gen rand_order2 = _n	

egen komp_1rb = max(komp_*(rand_order2==2)), by(rand_group)		
egen komp_2rb = max(komp_*(rand_order2==1)), by(rand_group)				

egen cv_1rb = max(cv_fe*(rand_order2==1)), by(rand_group)		
egen cv_2rb = max(cv_fe*(rand_order2==2)), by(rand_group)				

gen rand_diff_b = abs(komp_1rb - komp_2rb)  if cv_1rb!=cv_2rb

** Presenting differences as graphs
capture drop to_graph
gen to_graph = top2_diff*(which_order==3) + rand_diff*(which_order==1) + 1

forvalues i = 1/60{
	local i1 = `i' - 1
	label define diff_x  `i' "`i1'" , modify
}
label val to_graph diff_x

cdfplot to_graph if which_order!=2, by(which) xtitle("Differences between candidates") ///
			legend(order(2 "Top two candidates" 1 "Two random candidates") pos(5) ring(0) c(1)) ///
			xline(2) xsca(log) xlab(1(1)4 6  11 21 41 61 , valuelabel )


graph export ../output/cdfplot_differences.pdf , replace


** Presenting differences as a table
 
matrix results = J(11,3,.) 

local i = 0
quiet foreach vars in top2_diff  rand_diff rand_diff_b{

local i = `i' + 1

capture drop rec_var
recode `vars' (6/10 = 6) (11/20= 7) (21/100=8) , gen(rec_var)
	
tab rec_var   , matcell(aux)
mat results[1,`i'] = aux/r(N)

sum `vars' , d
mat results[10,`i'] = r(mean)\ r(p50)
	
	
}

 

matrix rownames results= "0" "1" "2" "3" "4" "5" "6-10" "11-20" "More than 20" "\hline Mean" "Median"
matrix colnames results = "Top 2 candidates" "2 candidates" "Random"

local printto using ../output/dist_differences.tex 
estout matrix(results, fmt(2)) `printto'  , sty(tex) replace ///
		prehead("\begin{tabular}{l ccc}" "\hline\hline" "%") posthead("\hline") ///
		prefoot("%") postfoot("\hline \hline" "\end{tabular}")

		
		
		
** How often will decision change if candidates of different gender?

* Same idea, but
** Compare always men to women
** Compare always different resumes
** Bootstrapping the differences

keep komp_ cv_fe female

tempfile lucas
tempfile lucas2

quiet forvalues i = 1/500{
	
	preserve
	tempvar random_var
	gen `random_var' = runiform()
	
 
	bys female (`random_var') : gen sorted = _n
    drop `random_var'	
	reshape wide komp  cv_fe , i(sorted) j(female)
	drop if cv_fe1 == cv_fe0
	sample 0.2 				// 100 / n_reps (500)
	
	if `i' ==1{
		save `lucas'
	}
	if `i' !=1{
		save `lucas2' , replace
		use `lucas'
		append using `lucas2' 
		save `lucas' , replace
	}

	restore
}

use `lucas' , clear


gen diff = komp_1 - komp_0   // diff > 0 -- women is preferred
recode diff (-100/-1 = -1) (6/10 = 6 "6-10") ( 11/20 = 7 "11-20") (21/99 = 8 "20 or higher")  , gen(tab_diff)

tab tab_diff
