*--------------------------------------------
*		Looking at outliers
*--------------------------------------------

use ../data/data_ready_202340425 , replace 

drop if mi(komp_)
egen group = group(TOKEN recruitment)
global stderr "vce(cluster group)"

label var komp_ "Assessed competence"
label define tt1 1 "HC" 2 "NHC"
label val treat1 tt1

label define bp 1 "Biographical profile #1" 2 "Biographical profile #2" 4 "Biographical profile #4"  5 "Biographical profile #5"  6 "Biographical profile #6"
label values cv_fe bp
 
** Boxplot to show the data
*----------------------------------

forvalues cv = 1/7{
	if `cv' == 3 continue
	*ttest komp_ if cv_fe == `cv', by(female) unequal	
	
	ksmirnov komp_ if cv_fe ==`cv' , by(female)
	local stars = cond(r(p)<0.01, "***" , cond(r(p)<0.05, "**", cond(r(p)<0.1, "*", "")))
	label def star_fe `cv' "`cv' `stars'" ,  modify

	
	} 
  
*label val cv_fe star_fe
graph box komp_  if cv_fe!=3 & cv_fe!=7, by(cv_fe, note(" ") col(5)) over(female)  xsize(6) ysize(2)
graph export ../output/boxplots.pdf, replace 
* Boxplots by cv + stars for equal/unequal means or distributions
* No stars because differences are not statistically significant in any case.


**#  Identifying outliers in each resume
*--------------------------------------------------

* Using quartiles
gen outlier_q_joint  = 0
gen outlier_q_gender = 0

* Using moments of a distribution
gen outlier_m_joint  = 0
gen outlier_m_gender = 0

quiet forvalues cv = 1/7{

	local ifs  cv_fe == `cv' & !mi(komp)
	quiet sum komp_ if `ifs', d
	local iqd = 1/2*(r(p75) - r(p25))
	
	replace outlier_q_joint = 1 if komp_ < r(p25) - 3 * `iqd' & `ifs'
	replace outlier_q_joint = 1 if komp_ > r(p75) + 3 * `iqd' & `ifs'
	
	replace outlier_m_joint = 1 if komp_ < r(mean) - 3 * r(sd) & `ifs'
	replace outlier_m_joint = 1 if komp_ > r(mean) + 3 * r(sd) & `ifs'
	
	
	foreach f in 1 0 {
	local ifs  cv_fe == `cv' & female== `f' & !mi(komp)
	quiet sum komp if `ifs' , d
	local iqd = 1/2*(r(p75) - r(p25))
	
	replace outlier_q_gender = 1 if komp_ < r(p25) - 3 * `iqd' &   `ifs'
	replace outlier_q_gender = 1 if komp_ > r(p75) + 3 * `iqd' &   `ifs'
	
	replace outlier_m_gender = 1 if komp_ < r(mean) - 3 * r(sd) &  `ifs'
	replace outlier_m_gender = 1 if komp_ > r(mean) + 3 * r(sd) &  `ifs'
	
	}
	}


**# What defines outliers
*--------------------------------

global x_resp "i.fem_respondent phd_year i.title i.part_rec i.discipline "
eststo who_out1: reg outlier_q_gender i.female##ib2.treat1 i.cv_fe $x_resp if cv_fe !=3
margins r.female@treat1

eststo who_out2:  reg outlier_q_joint i.female##ib2.treat1 i.cv_fe $x_resp if cv_fe !=3  
margins r.female@treat1

* Outliers are more common for female profiles under HC condition
* gender differences in control are not statistically significant


**# Who provides outliying answers? 
*-----------------------------------------------

bys TOKEN: egen sum_q_gender = sum(outlier_q_gender)
bys TOKEN: egen sum_q_joint = sum(outlier_q_joint)

gen any_q_gender = sum_q_gender > 0
gen any_q_joint  = sum_q_joint  > 0

tab any_q_gender if  fobs == 1 
* 45 individuals or roughly 9% of respondents provided an extreme score

tab sum_q_gender if  fobs == 1 & any_q_gender >0
* 26 had only one outlier, 12 had two, etc. 

reg any_q_gender $x_resp if fobs ==1   
* No defining feature, other than the unwillingness to declare participation in recruitenmts


**# What happens when we exclude outliers
*-------------------------------------------------------

eststo clear
foreach yvar in invite komp_{
local l = substr("`yvar'",1,1)

global mainx  "i.female##ib2.treat1 "

eststo h1_`l'_1: reg `yvar'   $mainx  i.cv_fe  $x_resp if cv_fe !=3 , $stderr 
eststo h1_`l'_2: reg `yvar'   $mainx  i.cv_fe  $x_resp if cv_fe !=3 & outlier_q_gender == 0, $stderr   
eststo h1_`l'_3: reg `yvar'   $mainx  i.cv_fe  $x_resp if cv_fe !=3 & any_q_gender == 0    , $stderr 

}

global opts1 se star(* .10 ** .05 *** .01) stat(N  r2  , label("Observations" "R-squared" ))
global nopes noomit nobase nonumbers nonotes

local print_to using "../output/results_outliers.tex"		
esttab who_out1 who_out2 h1_k* h1_i* `print_to' , keep(*female* *treat1*) $opts1 $nopes replace ///
		label  indicate("Resume FE = 2.cv_fe" "Respondent characteristics =phd_year" ) ///
		mgroups( "Where outliers" "Competences" "Invitation" , pattern(1 0 1 0 0 1 0 0) ///
		span prefix(\multicolumn{@span}{c}{) suffix(}))  ///
		mlab( Gender Joint Base "No obs" "No indiv" Base "No obs" "No indiv" )   

** How many observations to have a ``correct'' average?


